@@ -4,6 +4,7 @@ use Moose;
 our $VERSION = '0.0.1';
 use aliased 'App::SeismicUnixGui::messages::FileDialog_button_messages';
 use aliased 'App::SeismicUnixGui::messages::FileDialog_close_messages';
+use aliased 'App::SeismicUnixGui::messages::backup_project_selector_messages';
 use aliased 'App::SeismicUnixGui::messages::color_listbox_messages';
 use aliased 'App::SeismicUnixGui::messages::help_button_messages';
 use aliased 'App::SeismicUnixGui::misc::save_button_messages';
@@ -18,6 +19,7 @@ use aliased 'App::SeismicUnixGui::messages::superflow_messages';
 my $flows             = flows_messages->new();
 my $FileDialog_button = FileDialog_button_messages->new();
 my $FileDialog_close  = FileDialog_button_messages->new();
+my $backup_project_selector  = backup_project_selector_messages->new();
 my $help_button       = help_button_messages->new();
 my $run_button        = run_button_messages->new();
 my $save_button       = save_button_messages->new();
