@@ -78,6 +78,7 @@ our (@EXPORT_OK, @ISA); #Global variables
   $mute
   $temp 
   $fldr
+  $flip
   $ivpicks_sorted_par_
   $ms2s $us2s
   $offset 
@@ -231,6 +232,8 @@ our $_cdp = '_cdp';
 
 our $_mute = '_mute';
 
+our $flip  = 'flip';
+
 our $pick  = 'pick';
 
 our $pl    = 'pl';
