@@ -1,5 +1,8 @@
 package App::SeismicUnixGui::misc::name;
 
+# NOTE TODO will be deprecated in favor of program_name which self-defines 
+# global constants and uses hregex and ashes for quick searbch
+
 use Moose;
 our $VERSION = '0.0.1';
 use aliased 'App::SeismicUnixGui::misc::L_SU_global_constants';
@@ -9,8 +12,8 @@ my $get = L_SU_global_constants->new();
 my $superflow_names_aref = $get->superflow_names_aref();
 my @superflow_names_aref = @$superflow_names_aref;
 
-my $alias_superflow_names_aref = $get->alias_superflow_names_aref;
-my @alias_superflow_names_aref = @$alias_superflow_names_aref;
+#my $alias_superflow_names_aref = $get->alias_superflow_names_aref;
+#my @alias_superflow_names_aref = @$alias_superflow_names_aref;
 
 my $alias_superflow_config_names_aref = $get->alias_superflow_config_names_aref;
 my @alias_superflow_config_names_aref = @$alias_superflow_config_names_aref;
@@ -25,31 +28,31 @@ my $name = {
 
 };
 
-=head2 sub alias_superflow_names 
-
-=cut
-
-sub get_alias_superflow_names {
-    my ( $self, $name_in ) = @_;
-    my $name_out;
-    my $length = scalar(@alias_superflow_names_aref);
-
-    for ( my $i = 0 ; $i < $length ; $i++ ) {
-
-# print("1. name,get_alias_superflow_names,name_in= $$name_in\n");
-# print("1. name,get_alias_superflow_names, alias= $alias_superflow_names_aref[$i]\n");
+#=head2 sub alias_superflow_names 
+#
+#=cut
+#
+#sub get_alias_superflow_names {
+#    my ( $self, $name_in ) = @_;
+#    my $name_out;
+#    my $length = scalar(@alias_superflow_names_aref);
+#
+#    for ( my $i = 0 ; $i < $length ; $i++ ) {
+#
+# print("1. name,get_alias_superflow_names,name_in=$$name_in\n");
+## print("1. name,get_alias_superflow_names, alias= $alias_superflow_names_aref[$i]\n");
 # print("1. name,get_alias_superflow_names, superflow_names= $superflow_names_aref[$i]\n");
-
-        if ( $$name_in eq $superflow_names_aref[$i] ) {
-
-            # print("2. name,get_alias_superflow_names,name_in= $$name_in\n");
-            $name_out = $alias_superflow_names_aref[$i];
-
-            # print("2. name,get_alias_superflow_names, alias= $name_out\n");
-        }
-    }
-    return ($name_out);
-}
+#
+#        if ( $$name_in eq $superflow_names_aref[$i] ) {
+#
+#            # print("2. name,get_alias_superflow_names,name_in= $$name_in\n");
+#            $name_out = $alias_superflow_names_aref[$i];
+#
+#            print("2. name,get_alias_superflow_names, alias= $name_out\n");
+#        }
+#    }
+#    return ($name_out);
+#}
 
 =head2 sub change_config 
 
