@@ -1,8 +1,9 @@
 #!/bin/bash
 
-source ./.temp
-echo 'source .temp'
-
+local_dir=`pwd`
+# echo "local directory=$local_dir"
+source $local_dir/.temp
+echo "source $local_dir/.temp"
 # see if global variable is set
 # global variable SeismicUnixGuilocates main folder
 
