@@ -4,8 +4,8 @@ package App::SeismicUnixGui::sunix::model::suea2df;
 
 =head2 SYNOPSIS
 
- PACKAGE NAME:  SUEA2DF - SU version of (an)elastic anisotropic 2D finite difference 	
- AUTHOR: Juan Lorenzo
+ PERL PROGRAM NAME:  SUEA2DF - SU version of (an)elastic anisotropic 2D finite difference 	
+AUTHOR: Juan Lorenzo (Perl module only)
  DATE:   
  DESCRIPTION:
  Version: 
