@@ -2,8 +2,8 @@ package App::SeismicUnixGui::sunix::plot::lprop;
 
 =head2 SYNOPSIS
 true
-PACKAGE NAME:
-AUTHOR:  
+PERL PROGRAM NAME:
+AUTHOR: Juan Lorenzo (Perl module only)
 
 DATE:
 
