@@ -2,9 +2,9 @@ package App::SeismicUnixGui::sunix::plot::spsplot;
 
 =head2 SYNOPSIS
 
-PACKAGE NAME: 
+PERL PROGRAM NAME: 
 
-AUTHOR:  
+AUTHOR: Juan Lorenzo (Perl module only)
 
 DATE:
 
@@ -111,7 +111,7 @@ Version:
 
 
 
- AUTHOR:  Dave Hale, Colorado School of Mines, 10/18/90
+ Author:  Dave Hale, Colorado School of Mines, 10/18/90
 
  MODIFIED: Craig Artley, Colorado School of Mines, 03/27/94
 
