@@ -4,8 +4,8 @@ package App::SeismicUnixGui::sunix::plot::xgraph;
 
 =head2 SYNOPSIS
 
- PACKAGE NAME:  XGRAPH - X GRAPHer							
- AUTHOR: Juan Lorenzo
+ PERL PROGRAM NAME:  XGRAPH - X GRAPHer							
+AUTHOR: Juan Lorenzo (Perl module only)
  DATE:   
  DESCRIPTION:
  Version: 
